==> spring-issue-2.1.3-sources.jar: io/lsn/spring/issue/domain/entity/Issue.java <==
package io.lsn.spring.issue.domain.entity;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonView;
import io.lsn.spring.issue.domain.IssueInterface;
import io.lsn.spring.utilities.json.views.JsonViews;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@SuppressWarnings("squid:S1135")
@JsonIgnoreProperties(ignoreUnknown = true)
public abstract class Issue implements IssueInterface {

    private Long id;

    // issue number
    private String number;

    @JsonView(JsonViews.Internal.class)
    private Long uid;

    // issue subject
    private String subject;

    // issue body
    private String description;

    // issue registration date
    private LocalDateTime issueDate;

    // planned finish date for the task
    private LocalDateTime plannedDate;

    // list of additional attributes that describes issue
    private List<Attribute> attributeList;

    private Long referenceId;

    private String referenceType;

    private String externalUserId;

    /**
     * list of assigned users
     *
     * @return List
     */
    public abstract <U extends UserInterface> List<U> getAssigneeList();

    /**
     * list of assigned users
     *
     * @return List
     */
    public abstract <U extends UserInterface> List<U> getWatcherList();

    /**
     * returns type code
     *
     * @return
     */
    public abstract String getTypeCode();

    /**
     * get comment list
     *
     * @return
     */
    public abstract <U extends Comment> List<U> getCommentList();

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public String getSubject() {
        return subject;
    }

    public void setSubject(String subject) {
        this.subject = subject;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public LocalDateTime getIssueDate() {
        if (issueDate == null) {
            issueDate = LocalDateTime.now();
        }
        return issueDate;
    }

    public void setIssueDate(LocalDateTime issueDate) {
        this.issueDate = issueDate;
    }

    public LocalDateTime getPlannedDate() {
        return plannedDate;
    }

    public void setPlannedDate(LocalDateTime plannedDate) {
        this.plannedDate = plannedDate;
    }

    public List<Attribute> getAttributeList() {
        if (attributeList == null) {
            attributeList = new ArrayList<>();
        }
        return attributeList;
    }

    public void setAttributeList(List<Attribute> attributeList) {
        this.attributeList = attributeList;
    }

    public Long getReferenceId() {
        return referenceId;
    }

    public void setReferenceId(Long referenceId) {
        this.referenceId = referenceId;
    }

    public String getReferenceType() {
        return referenceType;
    }

    public void setReferenceType(String referenceType) {
        this.referenceType = referenceType;
    }

    public String getExternalUserId() {
        return externalUserId;
    }

    public void setExternalUserId(String externalUserId) {
        this.externalUserId = externalUserId;
    }

}

==> spring-issue-2.2.0-sources.jar: io/lsn/spring/issue/domain/entity/Issue.java <==
package io.lsn.spring.issue.domain.entity;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonView;
import io.lsn.spring.issue.domain.IssueInterface;
import io.lsn.spring.utilities.json.views.JsonViews;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@SuppressWarnings("squid:S1135")
@JsonIgnoreProperties(ignoreUnknown = true)
public abstract class Issue implements IssueInterface {

    private Long id;

    // issue number
    private String number;

    @JsonView(JsonViews.Internal.class)
    private Long uid;

    // issue subject
    private String subject;

    // issue body
    private String description;

    // issue registration date
    private LocalDateTime issueDate;

    // planned finish date for the task
    private LocalDateTime plannedDate;

    // list of additional attributes that describes issue
    private List<Attribute> attributeList;

    private Long referenceId;

    private String referenceType;

    private String externalUserId;

    /**
     * list of assigned users
     *
     * @return List
     */
    public abstract <U extends UserInterface> List<U> getAssigneeList();

    /**
     * list of assigned users
     *
     * @return List
     */
    public abstract <U extends UserInterface> List<U> getWatcherList();

    /**
     * returns type code
     *
     * @return
     */
    public abstract String getTypeCode();

    /**
     * get comment list
     *
     * @return
     */
    public abstract <U extends Comment> List<U> getCommentList();

    public Long getId() {
        return id;
    }

    public Issue setId(Long id) {
        this.id = id;
        return this;
    }

    public String getNumber() {
        return number;
    }

    public Issue setNumber(String number) {
        this.number = number;
        return this;
    }

    public Long getUid() {
        return uid;
    }

    public Issue setUid(Long uid) {
        this.uid = uid;
        return this;
    }

    public String getSubject() {
        return subject;
    }

    public Issue setSubject(String subject) {
        this.subject = subject;
        return this;
    }

    public String getDescription() {
        return description;
    }

    public Issue setDescription(String description) {
        this.description = description;
        return this;
    }

    public LocalDateTime getIssueDate() {
        if (issueDate == null) {
            issueDate = LocalDateTime.now();
        }
        return issueDate;
    }

    public Issue setIssueDate(LocalDateTime issueDate) {
        this.issueDate = issueDate;
        return this;
    }

    public LocalDateTime getPlannedDate() {
        return plannedDate;
    }

    public Issue setPlannedDate(LocalDateTime plannedDate) {
        this.plannedDate = plannedDate;
        return this;
    }

    public List<Attribute> getAttributeList() {
        if (attributeList == null) {
            attributeList = new ArrayList<>();
        }
        return attributeList;
    }

    public Issue setAttributeList(List<Attribute> attributeList) {
        this.attributeList = attributeList;
        return this;
    }

    public Long getReferenceId() {
        return referenceId;
    }

    public Issue setReferenceId(Long referenceId) {
        this.referenceId = referenceId;
        return this;
    }

    public String getReferenceType() {
        return referenceType;
    }

    public Issue setReferenceType(String referenceType) {
        this.referenceType = referenceType;
        return this;
    }

    public String getExternalUserId() {
        return externalUserId;
    }

    public Issue setExternalUserId(String externalUserId) {
        this.externalUserId = externalUserId;
        return this;
    }
}
